<?php

namespace Pudo\WooCommerce;

class Pudo_Api
{
    private $API_URL_BASE;
    private array $settings;
    private $API_URL = null;

    const API_METHODS = [
        'get_all_terminals'    => [
            'type'     => 'GET',
            'endpoint' => 'terminal/get/all',
        ],
        'booking_request'      => [
            'type'     => 'POST',
            'endpoint' => 'booking/request'
        ],
        'booking_confirmation' => [
            'type'     => 'GET',
            'endpoint' => 'booking/check/'
        ],
    ];
    /**
     * @var array
     */
    public array $terminals;

    /**
     * @var array
     */
    public $places;

    public function __construct(array $settings)
    {
        $this->API_URL = $this->API_URL_BASE . 'api/tcg/';

        try {
            $this->settings  = $settings;
            $this->terminals = $this->get_all_terminals();
        } catch (\Exception $exception) {
            die($exception->getMessage());
        }
    }

    public function booking_request($data)
    {
        return $this->call_pudo_api('booking_request', $data);
    }

    /**
     * @return array
     * @throws \Pudo\WooCommerce\Pudo_Api_Exception
     */
    public function get_all_terminals(): array
    {
        $terminalss = get_transient('pudo_terminals');
        if (!$terminalss) {
            $response = $this->call_pudo_api('get_all_terminals');
            if (is_array($response) && !empty($response['response']) && $response['response']['code'] === 200) {
                $t          = json_decode($response['body']);
                $terminalss = [];
                array_map(function ($terminal) use (&$terminalss) {
                    $terminalss[$terminal->id] = $terminal;
                }, $t);
                set_transient('pudo_terminals', $terminalss, 24 * 60 * 60);
            } else {
                $terminalss = [];
            }
        }

        return $terminalss;
    }

    public function booking_confirmation($transactionId)
    {
        return $this->call_pudo_api('booking_confirmation', $transactionId);
    }

    /**
     * @param string $method
     *
     * @return array|string|\WP_Error
     * @throws \Pudo\WooCommerce\Pudo_Api_Exception
     */
    private function call_pudo_api(string $method, $content = null)
    {
        if ((get_option('pudo_testmode') ?? "") === 'false') {
            $url = get_option(
                       'pudo_api_url'
                   ) . '/api/tcg/' . self::API_METHODS[$method]['endpoint'] . '?code=' . (get_option(
                                                                                              'pudo_account_key'
                                                                                          ) ?? '');
        } else {
            $url = 'https://ksttcgfunctionsv3-dev.azurewebsites.net/' . 'api/tcg/' . self::API_METHODS[$method]['endpoint'] . '?code=9rI7KWwxS/mxIvcs5nZi31JBxBV9iTzkadtjGG4TZ4PRxdZDJgui0g==';
        }

        $type     = self::API_METHODS[$method]['type'];
        $response = '';

        try {
            if ($type === 'GET') {
                if ($content) {
                    if (get_option('pudo_testmode') === 'true') {
                        $url = 'https://ksttcgfunctionsv3-dev.azurewebsites.net/api/tcg/' . self::API_METHODS[$method]['endpoint'] .
                               $content . '?code=9rI7KWwxS/mxIvcs5nZi31JBxBV9iTzkadtjGG4TZ4PRxdZDJgui0g==';
                    } else {
                        $url = get_option('pudo_api_url') . '/api/tcg/' . self::API_METHODS[$method]['endpoint'] .
                               $content .
                               '?code=' . get_option('pudo_account_key');
                    }
                }
                $response = wp_remote_get($url, ['timeout' => 30]);
            } elseif ($type === 'POST') {
                $response = wp_remote_post($url, [
                    'headers'     => ['Content-Type' => 'application/json; charset=utf-8'],
                    'body'        => $content,
                    'method'      => 'POST',
                    'data_format' => 'body',
                ],                         ['timeout' => 30]);
            }
        } catch (\Exception $exception) {
            return new Exception($exception->getMessage());
        }

        return $response;
    }
}
