<?php

namespace Pudo\WooCommerce;

class Pudo_Shipping_Settings
{
    const ADDRESS_LINE_1 = 'Address Line 1';
    const ADDRESS_LINE_2 = 'Address Line 2';
    const ADDRESS_LINE_3 = 'Address Line 3';

    /**
     * Generate the fields for settings for the plugin
     *
     */
    public static function overrideFormFieldsVariable(array $lockers = [])
    {
        $fields['title'] = [
            'title'   => __('Shipping Method Title'),
            'type'    => 'text',
            'label'   => __('Shipping Method Title'),
            'default' => 'PUDO',
        ];

        $fields['tax_status'] = [
            'title'       => __('Tax status', 'woocommerce'),
            'type'        => 'select',
            'options'     => ['taxable' => 'Taxable', 'none' => 'None'],
            'description' => __('VAT applies or not', 'woocommerce'),
            'default'     => __('taxable', 'woocommerce')
        ];

        //Pudo source
        $fields['pudo_source'] = [
            'title'   => __('Select locker or address as source'),
            'type'    => 'select',
            'options' => ['locker' => 'Locker', 'street' => 'Street Address'],
            'label'   => __('Select locker or address as source')
        ];

        $fields['pudo_locker_name'] = [
            'title'   => __('PUDO Locker Source 1'),
            'type'    => 'select',
            'options' => $lockers,
            'label'   => __('PUDO Locker Source'),
        ];

        $fields['pudo_locker_name_2'] = [
            'title'   => __('PUDO Locker Source 2'),
            'type'    => 'select',
            'options' => $lockers,
            'label'   => __('PUDO Locker Source'),
        ];

        $fields['pudo_locker_name_3'] = [
            'title'   => __('PUDO Locker Source 3'),
            'type'    => 'select',
            'options' => $lockers,
            'label'   => __('PUDO Locker Source'),
        ];

        $fields['other_settings'] = [
            'title' => __('Other Settings'),
            'type'  => 'title',
            'label' => __('Other Settings'),
        ];

        $fields['remove_waybill_description'] = [
            'title'       => __('Generic waybill description', 'woocommerce'),
            'type'        => 'checkbox',
            'description' => __(
                'When enabled, a generic product description will be shown on the waybill.',
                'woocommerce'
            ),
            'default'     => 'no'
        ];

        $fields['usemonolog'] = [
            'title'       => __('Enable WooCommerce Logging', 'woocommerce'),
            'type'        => 'checkbox',
            'description' => __(
                'Check this to enable WooCommerce logging for this plugin. Remember to empty out logs when done.',
                'woocommerce'
            ),
            'default'     => __('no', 'woocommerce'),
        ];

        $fields['locker_to_locker_special'] = [
            'title'       => __('Enable locker to locker special', 'woocommerce'),
            'type'        => 'checkbox',
            'label'       => 'Use Locker to Locker Promotion',
            'description' => __(
                'Check this to enable the Locker to Locker promotion. XS: R50.00. Small, Medium, Large, Extra Large: R60.',
                'woocommerce'
            ),
            'default'     => __('no', 'woocommerce'),
        ];
        $fields['free_shipping']            = [
            'title'       => __('Enable free shipping ', 'woocommerce'),
            'type'        => 'checkbox',
            'description' => __('This will enable free shipping over a specified amount', 'woocommerce'),
            'default'     => 'no'
        ];
        $fields['amount_for_free_shipping'] = [
            'title'             => __('Amount for free Shipping', 'woocommerce'),
            'type'              => 'number',
            'description'       => __('Enter the amount for free shipping when enabled', 'woocommerce'),
            'default'           => '1000',
            'custom_attributes' => [
                'min' => '0'
            ]
        ];

        //Sender contact details
        $fields['sender_contact'] = [
            'title'    => __('Name of Shop Contact'),
            'type'     => 'text',
            'label'    => __('Name of Sender'),
            'required' => true,
        ];
        $fields['sender_email']   = [
            'title'    => __('Email of Sender'),
            'type'     => 'text',
            'label'    => __('Sender Email'),
            'required' => true,
        ];
        $fields['sender_phone']   = [
            'title'    => __('Phone of Sender'),
            'type'     => 'text',
            'label'    => __('Sender Phone'),
            'required' => true,
        ];

        //Shop Addresses
        $fields['shop_addresses'] = [
            'title' => __('Shop Addresses (If Street Address selected as Source)'),
            'type'  => 'title',
            'label' => __('Shop Addresses'),
        ];

        $fields['sender_addressline1'] = [
            'title' => __(self::ADDRESS_LINE_1),
            'type'  => 'text',
            'label' => __(self::ADDRESS_LINE_1),
        ];
        $fields['sender_addressline2'] = [
            'title' => __(self::ADDRESS_LINE_2),
            'type'  => 'text',
            'label' => __(self::ADDRESS_LINE_2),
        ];
        $fields['sender_addressline3'] = [
            'title' => __(self::ADDRESS_LINE_3),
            'type'  => 'text',
            'label' => __(self::ADDRESS_LINE_3),
        ];
        $fields['sender_city']         = [
            'title' => __('City'),
            'type'  => 'text',
            'label' => __('City'),
        ];
        $fields['sender_suburb']       = [
            'title' => __('Suburb'),
            'type'  => 'text',
            'label' => __('Suburb'),
        ];
        $fields['sender_postal_code']  = [
            'title' => __('Postal Code'),
            'type'  => 'text',
            'label' => __('Postal Code'),
        ];

        return $fields;
    }

}
